
local o = SimpleDruidBar; if (o == nil) then return; end

-- Config_t_Init: ()
-- Config_OnEvent_VARIABLES_LOADED: ()
-- Config_HandleSlashCmd_SetFont: (args)
--
-- Config_SetTextStyle: (style)
-- Config_SetWidth: (width)
-- Config_SetHeight: (height)
	-- Config_SetupBarBorder: ()
-- Config_SetAlpha: (alpha)
-- Config_SetFont: (font, size, style)




function o.Config_t_Init()
	o.Config_t_Init = nil;
	
	SimpleDruidBar_DisplayBar:RegisterEvent("VARIABLES_LOADED");
	
	local cmds = o.Localization.SLASH_COMMANDS;
	local slashInfo = {
		[cmds.TEXT:match("^(%S+)")] = o.Config_SetTextStyle;
		[cmds.WIDTH:match("^(%S+)")] = o.Config_SetWidth;
		[cmds.HEIGHT:match("^(%S+)")] = o.Config_SetHeight;
		[cmds.ALPHA:match("^(%S+)")] = o.Config_SetAlpha;
		[cmds.FONT:match("^(%S+)")] = o.Config_HandleSlashCmd_SetFont;
		[false] = {
			cmds.UNKNOWN;
			cmds.TEXT;
			cmds.WIDTH;
			cmds.HEIGHT;
			cmds.ALPHA;
			cmds.FONT;
		};
	};
	NicheDevTools.RegisterSlashCommand("SimpleDruidBar", slashInfo, "/sdb");
end



function o.Config_OnEvent_VARIABLES_LOADED()
	o.Config_OnEvent_VARIABLES_LOADED = nil;
	
	local config = SimpleDruidBar_Config;
	if (config == nil) then
		config = {
			textStyle = 1;
			-- width = 120;
			-- height = 14;
			-- alpha = 1.0;
			-- font = ("Fonts\\ARIALN.ttf 14 OUTLINE");
			offsetX = (UIParent:GetWidth() / 2.0);
			offsetY = (UIParent:GetHeight() / 2.0);
			noEnergy = nil;
		};
		SimpleDruidBar_Config = config;
	else
		if (config.width == 120) then
			config.width = nil;
		end
		if (config.height == 14) then
			config.height = nil;
		end
		if (config.alpha == 1.0) then
			config.alpha = nil;
		end
		if (config.font == "Fonts\\ARIALN.ttf 14 OUTLINE" or config.font == "Fonts\\ARIALN.ttf:14:OUTLINE") then
			config.font = nil;
		end
	end
	
	o.Config_SetTextStyle(config.textStyle or 1);
	o.Display_DISPLAY_BAR:SetWidth(config.width or 120);
	o.Display_DISPLAY_BAR:SetHeight(config.height or 14);
	o.Config_SetupBarBorder();
	o.Display_DISPLAY_BAR:SetAlpha(config.alpha or 1.0);
	local font, size, style;
	if (config.font ~= nil) then
		font, size, style = config.font:match("^([^:]+):(%d+):?(.*)$");
		if (font == nil) then
			config.font = nil;
		end
	end
	if (font == nil) then
		font, size, style = ("Fonts\\ARIALN.ttf"), 14, ("OUTLINE");
	end
	o.Display_DISPLAY_BAR.TEXT:SetFont(font, size, style);
	
	o.Display_DISPLAY_BAR:SetPoint("CENTER", UIParent, "BOTTOMLEFT", config.offsetX, config.offsetY);
	
	o.Display_OnEvent_UNIT_DISPLAYPOWER("player");
end



function o.Config_HandleSlashCmd_SetFont(args)
	o.Config_SetFont(args:match("^([^:]+):(%d+):?(.*)$"));
end




function o.Config_SetTextStyle(style)
	style = tonumber(style);
	local bar = o.Display_DISPLAY_BAR;
	if (style == 1) then
		bar:SetScript("OnEnter", nil);
		bar:SetScript("OnLeave", nil);
		bar.TEXT:Show();
	elseif (style == 2) then
		bar:SetScript("OnEnter", (function(self) self.TEXT:Show(); end));
		bar:SetScript("OnLeave", (function(self) self.TEXT:Hide(); end));
		bar.TEXT:Hide();
	elseif (style == 3) then
		bar:SetScript("OnEnter", nil);
		bar:SetScript("OnLeave", nil);
		bar.TEXT:Hide();
	else
		error(("Invalid text style, %s."):format(tostring(style)), 2);
	end
	SimpleDruidBar_Config.textStyle = style;
end



function o.Config_SetWidth(width)
	width = tonumber(width);
	o.Display_DISPLAY_BAR:SetWidth(width);
	SimpleDruidBar_Config.width = width;
	o.Config_SetupBarBorder();
end


function o.Config_SetHeight(height)
	height = tonumber(height);
	o.Display_DISPLAY_BAR:SetHeight(height);
	SimpleDruidBar_Config.height = height;
	o.Config_SetupBarBorder();
end


function o.Config_SetupBarBorder()
	local bar = o.Display_DISPLAY_BAR;
	local border = SimpleDruidBar_DisplayBarBorder;
	border:ClearAllPoints();
	
	local widthOffset = math.ceil(bar:GetWidth() / 40);
	border:SetPoint("LEFT", bar, "LEFT", -widthOffset, 0);
	border:SetPoint("RIGHT", bar, "RIGHT", widthOffset, 0);
	
	local heightOffset = math.ceil(bar:GetHeight() / 4);
	border:SetPoint("TOP", bar, "TOP", 0, heightOffset);
	border:SetPoint("BOTTOM", bar, "BOTTOM", 0, -heightOffset);
end



function o.Config_SetAlpha(alpha)
	alpha = tonumber(alpha);
	o.Display_DISPLAY_BAR:SetAlpha(alpha);
	SimpleDruidBar_Config.alpha = alpha;
end



function o.Config_SetFont(font, size, style)
	o.Display_DISPLAY_BAR.TEXT:SetFont(font, size, style);
	local packed = (font .. ":" .. size);
	if (style ~= nil and style ~= "") then
		packed = (packed  .. ":" .. style);
	end
	SimpleDruidBar_Config.font = packed;
end
